==> neo4j-kernel-4.4.45-sources.jar: org/neo4j/kernel/api/query/LookupIndexUsage.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.query;

import java.util.HashMap;
import java.util.Map;

import org.neo4j.common.EntityType;

public class LookupIndexUsage extends IndexUsage
{
    private final String identifier;
    private final EntityType entityType;

    public LookupIndexUsage( String identifier, EntityType entityType )
    {
        super( identifier );
        this.identifier = identifier;
        this.entityType = entityType;
    }

    public EntityType getEntityType()
    {
        return entityType;
    }

    @Override
    public Map<String,String> asMap()
    {
        Map<String,String> map = new HashMap<>();
        map.put( "indexType", "LOOKUP INDEX" );
        map.put( "entityType", entityType.name() );
        map.put( "identifier", identifier );
        return map;
    }
}

==> neo4j-kernel-5.3.0-sources.jar: org/neo4j/kernel/api/query/LookupIndexUsage.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.query;

import java.util.HashMap;
import java.util.Map;
import org.neo4j.common.EntityType;

public class LookupIndexUsage extends IndexUsage {
    private final String identifier;
    private final EntityType entityType;

    public LookupIndexUsage(String identifier, EntityType entityType) {
        super(identifier);
        this.identifier = identifier;
        this.entityType = entityType;
    }

    public EntityType getEntityType() {
        return entityType;
    }

    @Override
    public Map<String, String> asMap() {
        Map<String, String> map = new HashMap<>();
        map.put("indexType", "LOOKUP INDEX");
        map.put("entityType", entityType.name());
        map.put("identifier", identifier);
        return map;
    }
}
